@@ -3,7 +3,7 @@
 ;;                     Patrick LoPresti <patl@lcs.mit.edu>
 ;;               1998  Brian Warner <warner@lothar.com>
 
-;; $Id: mc-gpg.el,v 1.3 1999/12/11 17:01:40 andreasj Exp $
+;; $Id: mc-gpg.el,v 1.15 2001/05/06 22:55:26 warner Exp $
 
 ;;{{{ Licensing
 ;; This file is intended to be used with GNU Emacs.
@@ -319,7 +319,7 @@ GPG ID.")
     (if (string= str "***** CONVENTIONAL *****") nil
       (let ((result (cdr-safe (assoc str mc-gpg-key-cache)))
 	    (key-regexp
-	     "^\\(sec\\|pub\\):[^:]*:[^:]*:[^:]*:\\([^:]*\\):[^:]*:[^:]*:[^:]*:[^:]*:\\([^:]*\\):$"
+	     "^\\(sec\\|pub\\):[^:]*:[^:]*:[^:]*:\\([^:]*\\):[^:]*:[^:]*:[^:]*:[^:]*:\\([^:]*\\):"
 	     )
 	    (obuf (current-buffer))
 	    buffer)
